@@ -49,7 +49,8 @@ class User(UserId):
 
     attributes = (
         'user_id', 'email', 'name', 'created_at', 'custom_data',
-        'last_seen_ip', 'last_seen_user_agent')
+        'last_seen_ip', 'last_seen_user_agent', 'last_impression_at',
+        'last_request_at', 'unsubscribed_from_emails')
 
     @classmethod
     def find(cls, user_id=None, email=None):
@@ -99,20 +100,17 @@ class User(UserId):
         return cls(resp)
 
     @classmethod
-    def create(
-            cls, user_id=None, email=None, name=None, created_at=None,
-            custom_data=None, last_seen_ip=None, last_seen_user_agent=None):
+    def create(cls, **kwargs):
         """ Create or update a user.
 
-        >>> user = User.create(email="somebody@example.com")
+        >>> user = User.create(email="somebody@example.com",last_impression_at=1400000000)
         >>> user.name
         u'Somebody'
+        >>> user.last_impression_at.year
+        2014
 
         """
-        resp = Intercom.create_user(
-            user_id=user_id, email=email, name=name, created_at=created_at,
-            custom_data=custom_data, last_seen_ip=last_seen_ip,
-            last_seen_user_agent=last_seen_user_agent)
+        resp = Intercom.create_user(**kwargs)
         return cls(resp)
 
     @classmethod
@@ -141,8 +139,15 @@ class User(UserId):
         u'first.user@example.com'
 
         """
-        resp = Intercom.get_users()
-        return [cls(u) for u in resp['users']]
+        page = 1
+        total_pages = 1
+        users = []
+        while page <= total_pages:
+            resp = Intercom.get_users(page=page)
+            page += 1
+            total_pages = resp.get('total_pages', 0)
+            users.extend([cls(u) for u in resp['users']])
+        return users
 
     def save(self):
         """ Creates or updates a User.
@@ -157,7 +162,7 @@ class User(UserId):
         attrs = {}
         for key in User.attributes:
             value = dict.get(self, key)
-            if value:
+            if value is not None:
                 attrs[key] = value
         resp = Intercom.update_user(**attrs)
         self.update(resp)
@@ -192,6 +197,18 @@ class User(UserId):
         """ Sets the last seen User Agent. """
         self['last_seen_user_agent'] = last_seen_user_agent
 
+    @property
+    def last_request_at(self):
+        """ Get last time this User interacted with your application. """
+        return dict.get(self, 'last_request_at', None)
+
+    @last_request_at.setter
+    @to_timestamp_property
+    def last_request_at(self, last_request_at):
+        """ Set time at which this User last made a request your application.
+        """
+        self['last_request_at'] = last_request_at
+
     @property
     def relationship_score(self):
         """ Returns the relationship score. """
@@ -209,6 +226,13 @@ class User(UserId):
         """ Returns the datetime this User last used your application. """
         return dict.get(self, 'last_impression_at', None)
 
+    @last_impression_at.setter
+    @to_timestamp_property
+    def last_impression_at(self, last_impression_at):
+        """ Set time at which this User last made a request your application.
+        """
+        self['last_impression_at'] = last_impression_at
+
     @property
     @from_timestamp_property
     def created_at(self):
@@ -262,6 +286,16 @@ class User(UserId):
             dict.__setitem__(self, 'location_data', data)
         return data
 
+    @property
+    def unsubscribed_from_emails(self):
+        """ Returns whether or not the user has unsubscribed from emails """
+        return dict.get(self, 'unsubscribed_from_emails', None)
+
+    @unsubscribed_from_emails.setter
+    def unsubscribed_from_emails(self, unsubscribed_from_emails):
+        """  Sets whether or not the user has unsubscribed from email """
+        self['unsubscribed_from_emails'] = unsubscribed_from_emails
+
     @property
     def custom_data(self):
         """ Returns a CustomData object for this User.
